@@ -11,7 +11,6 @@ log = logging.getLogger(__name__)
 
 
 class ErrormatorWSGIWrapper(object):
-
     __version__ = '0.3'
 
     def __init__(self, app, errormator_client):
@@ -39,21 +38,22 @@ class ErrormatorWSGIWrapper(object):
             # some bw. compat stubs
 
             def local_report(message, include_traceback=True,
-                                 http_status=200):
+                             http_status=200):
                 environ['errormator.force_send'] = True
 
             def local_log(level, message):
                 environ['errormator.force_send'] = True
+
             environ['errormator.report'] = local_report
             environ['errormator.log'] = local_log
 
         try:
             app_iter = self.app(environ, detect_headers)
             return app_iter
-        except Exception as e:
+        except Exception as exc:
             if hasattr(app_iter, 'close'):
                 app_iter.close()
-            # we need that here
+                # we need that here
 
             traceback = get_current_traceback(skip=1, show_hidden_frames=True,
                                               ignore_system_exceptions=True)
@@ -62,12 +62,12 @@ class ErrormatorWSGIWrapper(object):
                 raise
             try:
                 start_response('500 INTERNAL SERVER ERROR',
-                        [('Content-Type', 'text/html; charset=utf-8')])
-            except Exception as e:
+                               [('Content-Type', 'text/html; charset=utf-8')])
+            except Exception as exc:
                 environ['wsgi.errors'].write(
-            'ErrormatorWSGIWrapper middleware catched exception in streamed'
-            ' response at a point where response headers were already'
-            ' sent.\n')
+                    'ErrormatorWSGIWrapper middleware catched exception '
+                    'in streamed response at a point where response headers '
+                    'were already sent.\n')
             else:
                 return 'Server Error'
         finally:
@@ -85,15 +85,17 @@ class ErrormatorWSGIWrapper(object):
             if traceback and self.errormator_client.config['report_errors']:
                 http_status = 500
             elif (self.errormator_client.config['report_404'] and
-                  detected_data and detected_data[0] == '404'):
+                      detected_data and detected_data[0] == '404'):
                 http_status = int(detected_data[0])
             else:
                 http_status = None
             if http_status:
-                self.errormator_client.py_report(environ, traceback,
-                                                 message=None,
-                                                 http_status=http_status,
-                    start_time=datetime.datetime.utcfromtimestamp(start_time),
+                self.errormator_client.py_report(
+                    environ, traceback,
+                    message=None,
+                    http_status=http_status,
+                    start_time=datetime.datetime.utcfromtimestamp(
+                        start_time),
                     request_stats=stats)
                 # dereference
                 del traceback
@@ -104,19 +106,24 @@ class ErrormatorWSGIWrapper(object):
                 # do we have slow calls ?
                 if (delta >= self.errormator_client.config['slow_request_time']
                     or slow_calls):
-                    self.errormator_client.py_slow_report(environ,
-                            datetime.datetime.utcfromtimestamp(start_time),
-                            datetime.datetime.utcfromtimestamp(end_time),
-                            slow_calls, request_stats=stats)
+                    self.errormator_client.py_slow_report(
+                        environ,
+                        datetime.datetime.utcfromtimestamp(start_time),
+                        datetime.datetime.utcfromtimestamp(end_time),
+                        slow_calls,
+                        request_stats=stats)
                     # force log fetching
                     traceback = True
             if self.errormator_client.config['logging']:
                 records = self.errormator_client.log_handler.get_records()
                 self.errormator_client.log_handler.clear_records()
-                self.errormator_client.py_log(environ, records=records,
-                                    r_uuid=environ['errormator.request_id'],
-                                    traceback=traceback)
-            # send all data we gathered immediately at the end of request
+                self.errormator_client.py_log(
+                    environ,
+                    records=records,
+                    r_uuid=environ[
+                        'errormator.request_id'],
+                    traceback=traceback)
+                # send all data we gathered immediately at the end of request
             self.errormator_client.check_if_deliver(
-                    self.errormator_client.config['force_send'] or
-                    environ.get('errormator.force_send'))
+                self.errormator_client.config['force_send'] or
+                environ.get('errormator.force_send'))
